/*++
// THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY OF
// ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO
// THE IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
// PARTICULAR PURPOSE.
//
// Copyright (c) Microsoft Corporation. All rights reserved
//
// Module:
//      BadgeSensorDevice.h
//
// Description:
//      Defines the CBadgeSensorDevice container class

--*/


#pragma once

class CBadgeSensorDevice
{
public:
    CBadgeSensorDevice();
    ~CBadgeSensorDevice();
    
    HRESULT     Initialize(SensorType sensType);
    HRESULT     Uninitialize(VOID);

    HRESULT     GetSupportedProperties(IPortableDeviceKeyCollection **ppKeys);
    HRESULT     GetSupportedDataFields(IPortableDeviceKeyCollection **ppKeys);

    HRESULT     GetSettableProperties(IPortableDeviceKeyCollection **ppKeys);

    DWORD       GetSubscriberCount(void);
    SensorType  GetSensorType(void){ return m_SensorType; }
    CComBSTR    GetSensorObjectID(void) { return g_SupportedSensors[m_SensorType]; }
 
    HRESULT     GetProperty(REFPROPERTYKEY key, PROPVARIANT *pValue);
    HRESULT     GetDataField(REFPROPERTYKEY key, PROPVARIANT *pValue);
    HRESULT     GetAllDataFieldValues(IPortableDeviceValues* pValues);

    HRESULT     SetProperty(REFPROPERTYKEY key, const PROPVARIANT *pValue);
    HRESULT     SetDataField(REFPROPERTYKEY key, const PROPVARIANT *pValue);
    HRESULT     SetTimeStamp();

    VOID        Subscribe();
    VOID        Unsubscribe();

    HRESULT     RemoveProperty(REFPROPERTYKEY key);
    HRESULT     RemoveDataField(REFPROPERTYKEY key);

    BOOL        IsInitialized(VOID) { return m_fBadgeSensorDeviceInitialized; }

    VOID        RaiseDataEvent();
    BOOL        HasValidDataEvent();

    VOID        SetDataEventHandle(HANDLE hEvent) { m_hBadgeDriverEvent = hEvent; }

    HRESULT     SetUniqueID(__in IWDFDevice* pWdfDevice);


private:

    HRESULT InitializeAmbientLight(VOID);
    HRESULT InitializeAccelerometer(VOID);
    HRESULT InitializeSwitchArrayLeft(VOID);
    HRESULT InitializeSwitchArrayRight(VOID);

    HRESULT AddAmbientLightPropertyKeys();
    HRESULT AddAmbientLightDataFieldKeys();
    HRESULT AddAccelerometerPropertyKeys();
    HRESULT AddAccelerometerDataFieldKeys();
    HRESULT AddSwitchArrayPropertyKeys();
    HRESULT AddSwitchArrayDataFieldKeys();

    HRESULT SetAccelerometerDefaultValues();
    HRESULT SetAmbientLightDefaultValues();
    HRESULT SetSwitchArrayLeftDefaultValues();
    HRESULT SetSwitchArrayRightDefaultValues();

    HRESULT SetSettableSensorProperties();
    
    // PropertyKeys
    CComPtr<IPortableDeviceKeyCollection>   m_pSupportedSensorProperties;
    CComPtr<IPortableDeviceKeyCollection>   m_pSupportedSensorDataFields;
    CComPtr<IPortableDeviceKeyCollection>   m_pSettableSensorProperties;

    // Values
    CComPtr<IPortableDeviceValues>          m_pSensorProperties;
    CComPtr<IPortableDeviceValues>          m_pSensorDataFields;

    CComAutoCriticalSection                 m_CriticalSection; // This is used to make all calls to get/set properties thread safe
    
    BOOL                                    m_fBadgeSensorDeviceInitialized;    // flag checks if we have been initialized
    DWORD                                   m_dwEventSubscribers;               // count of subscribers

    SensorType                              m_SensorType;

    HANDLE                                  m_hBadgeDriverEvent;            // Handle to the Eventing thread proc
    BOOL                                    m_fValidDataEvent;                       // flag that indicates an event needs to be fired

};

typedef CAtlList<CBadgeSensorDevice*> SENSOR_LIST;

// the object used by the driver to get sensor data
extern SENSOR_LIST g_pSensorList;