/*++

// THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY OF
// ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO
// THE IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
// PARTICULAR PURPOSE.
//
// Copyright (c) Microsoft Corporation. All rights reserved


Module Name:

    WpdObjectProperties.h

Abstract:

    This module contains the type definitions for the 
    WpdObjectProperties class
--*/

#pragma once

#include "Defines.h"

HRESULT AddSupportedPropertyKeys(__in LPWSTR wszObjectID, __out IPortableDeviceKeyCollection*  pKeys);
HRESULT AddSupportedDataFieldKeys(__in LPWSTR wszObjectID, __out IPortableDeviceKeyCollection* pKeys);

VOID    AddCommonPropertyKeys(IPortableDeviceKeyCollection* pKeys);
VOID    AddDevicePropertyKeys(IPortableDeviceKeyCollection* pKeys);

HRESULT AddSensorPropertyKeys(SensorType sensType,IPortableDeviceKeyCollection* pKeys);
HRESULT AddSensorDataFieldKeys(SensorType sensType,IPortableDeviceKeyCollection* pKeys);

BOOL    FindPropertyKey(PROPERTYKEY Key, IPortableDeviceKeyCollection *pKeys);
BOOL    IsSettablePropertyKey(PROPERTYKEY Key);

HRESULT FindSensorTypeFromObjectID(__in LPWSTR pwszObjectID, __out SensorType* pSensorType);

class WpdObjectProperties
{
public:
    WpdObjectProperties();
    virtual ~WpdObjectProperties();

    HRESULT Initialize();
    HRESULT ProcessAsynchRead( BYTE* buffer, ULONG length );

    HRESULT OnGetSupportedProperties(
        __in LPWSTR  wszObjectID,
        IPortableDeviceKeyCollection** ppPortableDeviceKeyCollection
        );

    HRESULT OnGetSupportedDataFields(
        __in LPWSTR  wszObjectID,
        IPortableDeviceKeyCollection** ppPortableDeviceKeyCollection
        );

    HRESULT OnGetPropertyValues(
        __in LPWSTR  wszObjectID,
        IPortableDeviceKeyCollection* pKeys,
        IPortableDeviceValues** ppPortableDeviceValues
        );

    HRESULT OnGetDataFields(
        __in LPWSTR  wszObjectID,
        IPortableDeviceKeyCollection* pKeys,
        IPortableDeviceValues** ppPortableDeviceValues
        );

    HRESULT OnSetPropertyValues(
        __in LPWSTR  wszObjectID,
        IPortableDeviceValues* pValues,
        IPortableDeviceValues** ppResults
        );

    HRESULT OnGetPropertyAttributes(IPortableDeviceValues*  pParams,
                                    IPortableDeviceValues*  pResults);

    HRESULT OnDeleteProperties(IPortableDeviceValues*  pParams,
                               IPortableDeviceValues*  pResults);

    HRESULT OnClientSubscribeToEvents(__in LPWSTR pwszObjectID);
    HRESULT OnClientUnsubscribeToEvents(__in LPWSTR pwszObjectID);

private:

    HRESULT GetPropertyValuesForObject(LPCWSTR                        wszObjectID,
                                       IPortableDeviceKeyCollection*  pKeys,
                                       IPortableDeviceValues*         pValues);

    HRESULT GetDataValuesForObject(LPCWSTR                        wszObjectID,
                                       IPortableDeviceKeyCollection*  pKeys,
                                       IPortableDeviceValues*         pValues);

    HRESULT GetPropertyAttributesForObject(LPCWSTR                wszObjectID,
                                           const PROPERTYKEY&     Key,
                                           IPortableDeviceValues* pAttributes);

    HRESULT ConvertByteToFloat(__in DWORD Id, __in BYTE ByteData, __out FLOAT *pFloatData);

};